/*
 * Project name:
     Soft_I2C Advanced (Advanced Soft_I2C Example)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This example features the advanced communication with the 24AA01 EEPROM chip
     by introducing its own library of functions for this task: init, single
     write, single and sequential read. It performs write of a sequence of bytes
     (characters) into the EEPROM and writes this out at the first row on Lcd.
     Then, data read from EEPROM is performed and the result is displayed at the
     second row on Lcd.
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf
     Dev.Board:       UNI-DS6
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      External Clock 10.0000 MHz
     Ext. Modules:    -
     SW:              mikroC for 8051 v1.0
                      http://www.mikroe.com/en/compilers/mikroc/8051/
 * NOTES:
     - Turn on LCD/GLCD Control switches at SW15.5 and SW15.6 (board specific).
     - Turn on LCD Data switches at SW17 (board specific).
     - Turn on LCD backlight at SW18.7 (board specific).
     - Turn on I2C switches SW13.5 and SW13.6. (board specific)
     - Pull-up Soft I2C communication lines, P1.0 and P1.1,
       place jumper J2 in upper position. (board specific)
*/

#include "EEPROM_24AA01.h"

// Software I2C connections
sbit Soft_I2C_Scl at P1_0_bit;
sbit Soft_I2C_Sda at P1_1_bit;
// End Software I2C connections

// LCD module connections
sbit LCD_RS at P1_2_bit;
sbit LCD_EN at P1_5_bit;

sbit LCD_D4 at P2_4_bit;
sbit LCD_D5 at P2_5_bit;
sbit LCD_D6 at P2_6_bit;
sbit LCD_D7 at P2_7_bit;
// End LCD module connections

char someData[] = "Soft I2C mikroE";
char i ,tmpdata;

//  Main
void main() {

  EEPROM_24AA01_Init();                         // performs Soft_I2C initialization
  Lcd_Init();                                   // performs Lcd initialization
  Lcd_Cmd(_LCD_CLEAR);                          // clear Lcd
  Lcd_Cmd(_LCD_CURSOR_OFF);                     // set cursor off

  // Example for single-byte write
  i = 0;
  tmpdata = 1;
  while ((tmpdata = someData[i]) != 0) {
    i++;
    EEPROM_24AA01_WrSingle(i, tmpdata);         // writes data, char by char, in the EEPROM
    Delay_ms(20);
    Lcd_Chr(1,i, tmpdata);                      // diplays data on the first row of the Lcd
  }
  EEPROM_24AA01_WrSingle(i+1, 0);               // writes string termination
  Delay_ms(20);

  // Example for single-byte read
  i = 1;
  tmpdata = 1;
  while ((tmpdata = EEPROM_24AA01_RdSingle(i)) != 0) {
    Lcd_Chr(2,i, tmpdata);                      // displays data from EEPROM on the second row of the Lcd
    Delay_ms(20);
    i++ ;
  }

//  Example for sequential data read
//  Lcd_Cmd(_LCD_CLEAR);
//  EEPROM_24AA01_RdSeq(1, someData, 10);
//  Lcd_Out(2,1,someData);
}
