/*
 * Project name:
     Soft_I2C Simple (Simple test of Soft_I2C library routines)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This program demonstrates usage of the Soft_I2C library routines. It
     establishes Soft_I2C bus communication with 24AA01 EEPROM chip, writes one byte
     of data on some location, then reads it and displays it on PORTC.
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf
     Dev.Board:       UNI-DS6
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      External Clock 10.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for 8051
                      http://www.mikroe.com/en/compilers/mikroc/8051/
 * NOTES:
     - Turn on I2C switches SW13.5 and SW13.6. (board specific)
     - Pull-up Soft I2C communication lines, P1.0 and P1.1,
       place jumper J2 in upper position. (board specific)
     - Turn off PORTB LEDs (SW12.3). (board specific)
     - Turn on PORTC LEDs (SW12.2). (board specific)
*/

// Software I2C connections
sbit Soft_I2C_Scl at P1_0_bit;
sbit Soft_I2C_Sda at P1_1_bit;
// End Software I2C connections

void main(){
  P2 = 0;                        // Set P2 to 0

  Soft_I2C_Init();               // initialize Soft_I2C communication
  Soft_I2C_Start();              // issue Soft_I2C start signal
  Soft_I2C_Write(0xA2);          // send byte via Soft_I2C (device address + W)
  Soft_I2C_Write(2);             // send byte (address of EEPROM location)
  Soft_I2C_Write(0xAA);          // send data (data to be written)
  Soft_I2C_Stop();               // issue Soft_I2C stop signal

  Delay_100ms();

  Soft_I2C_Start();              // issue Soft_I2C start signal
  Soft_I2C_Write(0xA2);          // send byte via Soft_I2C (device address + W)
  Soft_I2C_Write(2);             // send byte (data address)
  Soft_I2C_Stop();               // issue Soft_I2C stop signal

  Soft_I2C_Start();              // issue Soft_I2C start signal
  Soft_I2C_Write(0xA3);          // send byte (device address + R)
  P2 = Soft_I2C_Read(0u);        // Read the data (NO acknowledge)
  Soft_I2C_Stop();               // issue Soft_I2C stop signal
}
