/*
 * Project name:
     DEMO 
 * Copyright:
     (c) Mikroelektronika, 2011.
 * Description:
     This project is a simple demonstration of working with the 2.7V 4-Channel
     12-bit A/D Converter(MCP3204) with SPI Serial Interface.
     The values measured on Channel 0 are being sent to PC via UART.
 * Test configuration:
     MCU:             LPC2214
     Dev.Board:       UNIDS6
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      14.74568MHz (cclk = 58.98272MHz, Fcco = 235.93088 MHz)
     Ext. Modules:    -
     SW:              KEIL uVision v4.10
 * NOTES:
     - Be sure to connect the USB cable to the USB UART 1 communication port and to turn ON switches SW13.1 and SW13.2.
     - Turn on SPI1 switches at SW14.1, SW14.1 and SW14.3. (board specific)
     - Turn on ADC-CS at SW13.7. (board specific)
     - Turn on voltage reference at SW12.8!
*/

#include <LPC22XX.H>

#include  "Serial.h"
#include  "Utility.h"
#include  "SPIhw.h"

unsigned short measurement, lastValue;
unsigned char
	txt[9];

void Init() {
  PINSEL0 = 0;
  PINSEL1 = 0;
  PINSEL2 &= 0x0000000C;
  PINSEL2 |= 0x00000030;

  DelayProc(0.2 * CCLOCK);

  UART0_init(38400/*bps*/, 14745/*kHz*/, length_8_bit, stop_bit_1, parity_disable, parity_odd);
  lastValue = 1;                                 // Initialize and make them
  measurement = 0;                               // different

  // Enable hardware SPI0 in mode 1,1 and with clock rate PCLK / 100
  SPI_init(&IOPIN0, 25, 100/*SPCCR*/, 1/*CPOL*/, 1/*CPHA*/);
  DelayProc(0.2 * CCLOCK);
}

unsigned int getADC(unsigned short channel) {    // Returns 0..4095
  unsigned short tmp;
  SPI_enable();                                  // Select MCP3204
  SPI_char(0x06);                                // SPI communication using 8-bit segments
  channel = channel << 6;                        // Bits 7 & 6 define ADC input
  tmp = SPI_char(channel) & 0x0F;
  tmp = tmp << 8;                                // Get ADC value
  tmp |= SPI_char(0);
  SPI_disable();
  return tmp;
}

void processValue(unsigned short pv) {           // Writes measured values to LEDs in the 8-levels mode
  if (lastValue != pv) {                         // Write value only if different than previous

   lastValue = pv;
  // Send measured value to PC via UART
   int2str (txt, pv);
   UART0_sendstring (txt);
   UART0_sendstring ("\n");
  }
}

// main procedure
int main() {

  Init();                                        // Initialize SPI

  while (1) {
    measurement = getADC(0);                     // Get ADC result from Channel 0
    processValue(measurement);                   // Send measured value to PC via UART
    DelayProc(0.02 * CCLOCK);
  }
}
