/*
 * Project name:
     GLCD_Test (Demonstration of the GLCD library routines)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This is a simple demonstration of the GLCD library routines:
     - Init and Clear (pattern fill)
     - Image display
     - Basic geometry - lines, circles, boxes and rectangles
     - Text display and handling
 * Test configuration:
     MCU:             ATmega128
                      http://www.atmel.com/dyn/resources/prod_documents/doc2467.pdf
     Dev.Board:       UNI-DS6 - ac:GLCD
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      External Clock 10.0000 MHz
     Ext. Modules:    GLCD 128x64, KS108/107 controller
                      http://www.mikroe.com/eng/products/view/277/various-components/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
 * Notes:
     - Turn on LCD/GLCD Control switches at SW15 (board specific).
     - Turn on GLCD Data switches at SW17 (board specific).
     - Turn on GLCD backlight at SW18.8 (board specific).
*/

//Declarations------------------------------------------------------------------
const code char truck_bmp[1024];
//--------------------------------------------------------------end-declarations

// Glcd module connections
char GLCD_DataPort at PORTC;
char GLCD_DataPort_Direction at DDRC;

sbit GLCD_CS1 at PORTB0_bit;
sbit GLCD_CS2 at PORTB1_bit;
sbit GLCD_RS  at PORTB2_bit;
sbit GLCD_RW  at PORTB3_bit;
sbit GLCD_EN  at PORTB5_bit;
sbit GLCD_RST at PORTB4_bit;

sbit GLCD_CS1_Direction at DDB0_bit;
sbit GLCD_CS2_Direction at DDB1_bit;
sbit GLCD_RS_Direction  at DDB2_bit;
sbit GLCD_RW_Direction  at DDB3_bit;
sbit GLCD_EN_Direction  at DDB5_bit;
sbit GLCD_RST_Direction at DDB4_bit;
// End Glcd module connections

void delay2S(){                                // 2 seconds delay function
  Delay_ms(2000);
}

void main() {                       
  char counter;
  char *someText;

  Glcd_Init();                                 // Initialize GLCD
  Glcd_Fill(0x00);                             // Clear GLCD

  while(1) {
    Glcd_Image(truck_bmp);                     // Draw image
    Delay2s(); Delay2s();
    Glcd_fill(0x00);                                  // Clear GLCD
    Glcd_PartialImage(0,0,68,30,128,64,truck_bmp);    // Partial image
    Delay_ms(500);
    Glcd_PartialImage(24,16,68,30,128,64,truck_bmp);
    Delay_ms(500);
    Glcd_PartialImage(56,34,68,30,128,64,truck_bmp);
    Delay2s(); Delay2s();
    Glcd_Fill(0x00);                           // Clear GLCD

    Glcd_Box(62,40,124,56,1);                  // Draw box
    Glcd_Rectangle(5,5,84,35,1);               // Draw rectangle
    Delay_ms(1000);
    Glcd_Rectangle_Round_Edges(2,2,87,38,7,1);
    Delay_ms(1000);
    Glcd_Rectangle_Round_Edges_Fill(8,8,81,32,12,1);
    Delay_ms(1000);
    Glcd_Line(0, 0, 127, 63, 1);               // Draw line
    Delay2s();

    for(counter = 5; counter < 60; counter+=5 ){ // Draw horizontal and vertical lines
      Delay_ms(250);
      Glcd_V_Line(2, 54, counter, 1);
      Glcd_H_Line(2, 120, counter, 1);
    }
    Delay2s();

    Glcd_Fill(0x00);                             // Clear Glcd
    Glcd_Set_Font(Character8x7, 8, 7, 32);       // Choose font, see __Lib_GLCDFonts.c in Uses folder
    Glcd_Write_Text("mikroE", 5, 7, 2);          // Write string

    for (counter = 1; counter <= 10; counter++)  // Draw circles
      Glcd_Circle(63,32, 3*counter, 1);
    Delay2s();
    
    Glcd_Circle_Fill(63,32, 30, 1);            // Draw circles
    Delay2S();

    Glcd_Box(12,20, 70,57, 2);                 // Draw box
    Delay2s();
    
    Glcd_Fill(0xFF);                           // Fill Glcd
    
    Glcd_Set_Font(Character8x7, 8, 7, 32);     // Change font
    someText = "8x7 Font";
    Glcd_Write_Text(someText, 5, 0, 2);        // Write string
    Delay2s();

    Glcd_Set_Font(System3x5, 3, 5, 32);        // Change font
    someText = "3X5 CAPITALS ONLY";
    Glcd_Write_Text(someText, 60, 2, 2);       // Write string
    Delay2s();
    
    Glcd_Set_Font(font5x7, 5, 7, 32);          // Change font
    someText = "5x7 Font";
    Glcd_Write_Text(someText, 5, 4, 2);        // Write string
    Delay2s();
    
    Glcd_Set_Font(FontSystem5x7_v2, 5, 7, 32);   // Change font
    someText = "5x7 Font (v2)";
    Glcd_Write_Text(someText, 50, 6, 2);         // Write string
    Delay2s();
  }
}