/*
 * Project name:
     GLCD_Test (Demonstration of the GLCD library routines)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This is a simple demonstration of the GLCD library routines:
     - Init and Clear (pattern fill)
     - Image display
     - Basic geometry - lines, circles, boxes and rectangles
     - Text display and handling
 * Test configuration:
     MCU:             dsPIC30F6014A
                      http://ww1.microchip.com/downloads/en/DeviceDoc/70143D.pdf
     Dev.Board:       UNI-DS6 - ac:GLCD
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      XT-PLL8, 80.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
 * NOTES:
     - Turn on LCD/GLCD Control switches at SW15 (board specific).
     - Turn on GLCD Data switches at SW16 (board specific).
     - Turn on GLCD backlight at SW18.8 (board specific).
 */

//Declarations------------------------------------------------------------------
const code char truck_bmp[1024];
//--------------------------------------------------------------end-declarations

// Glcd module connections
sbit GLCD_D7 at RD7_bit;
sbit GLCD_D6 at RD6_bit;
sbit GLCD_D5 at RD5_bit;
sbit GLCD_D4 at RD4_bit;
sbit GLCD_D3 at RD3_bit;
sbit GLCD_D2 at RD2_bit;
sbit GLCD_D1 at RD1_bit;
sbit GLCD_D0 at RD0_bit;
sbit GLCD_D7_Direction at TRISD7_bit;
sbit GLCD_D6_Direction at TRISD6_bit;
sbit GLCD_D5_Direction at TRISD5_bit;
sbit GLCD_D4_Direction at TRISD4_bit;
sbit GLCD_D3_Direction at TRISD3_bit;
sbit GLCD_D2_Direction at TRISD2_bit;
sbit GLCD_D1_Direction at TRISD1_bit;
sbit GLCD_D0_Direction at TRISD0_bit;

sbit GLCD_CS1 at LATB0_bit;
sbit GLCD_CS2 at LATB1_bit;
sbit GLCD_RS  at LATB2_bit;
sbit GLCD_RW  at LATB3_bit;
sbit GLCD_EN  at LATB5_bit;
sbit GLCD_RST at LATB4_bit;
sbit GLCD_CS1_Direction at TRISB0_bit;
sbit GLCD_CS2_Direction at TRISB1_bit;
sbit GLCD_RS_Direction  at TRISB2_bit;
sbit GLCD_RW_Direction  at TRISB3_bit;
sbit GLCD_EN_Direction  at TRISB5_bit;
sbit GLCD_RST_Direction at TRISB4_bit;
// End Glcd module connections

void delay2S(){                                  // 2 seconds delay function
  Delay_ms(2000);
}

void main() {
  char counter;
  char *someText;

  ADPCFG = 0xFFFF;                               // Configure AN pins as digital

  Glcd_Init();                                   // Initialize GLCD
  Glcd_Fill(0x00);                               // Clear GLCD

  while(1) {
    Glcd_Image(truck_bmp);                       // Draw image
    Delay2s(); Delay2s();
    Glcd_fill(0x00);                                // Clear GLCD
    Glcd_PartialImage(0,0,68,30,128,64,truck_bmp);  // Partial image
    Delay_ms(500);
    Glcd_PartialImage(24,16,68,30,128,64,truck_bmp);
    Delay_ms(500);
    Glcd_PartialImage(56,34,68,30,128,64,truck_bmp);
    Delay2s(); Delay2s();
    Glcd_Fill(0x00);                             // Clear GLCD

    Glcd_Box(62,40,124,56,1);                    // Draw box
    Glcd_Rectangle(5,5,84,35,1);                 // Draw rectangle
    Delay_ms(1000);
    Glcd_Rectangle_Round_Edges(2,2,87,38,7,1);
    Delay_ms(1000);
    Glcd_Rectangle_Round_Edges_Fill(8,8,81,32,12,1);
    Delay_ms(1000);
    Glcd_Line(0, 0, 127, 63, 1);                 // Draw line
    Delay2s();

    for(counter = 5; counter < 60; counter+=5 ){ // Draw horizontal and vertical lines
      Delay_ms(250);
      Glcd_V_Line(2, 54, counter, 1);
      Glcd_H_Line(2, 120, counter, 1);
    }
    Delay2s();

    Glcd_Fill(0x00);                             // Clear Glcd
    Glcd_Set_Font(Character8x7, 8, 7, 32);       // Choose font, see __Lib_GLCDFonts.c in Uses folder
    Glcd_Write_Text("mikroE", 5, 7, 2);          // Write string

    for (counter = 1; counter <= 10; counter++)  // Draw circles
      Glcd_Circle(63,32, 3*counter, 1);
    Delay2s();

    Glcd_Circle_Fill(63,32, 30, 1);              // Draw circles
    Delay2s();

    Glcd_Box(12,20, 70,57, 2);                   // Draw box
    Delay2s();

    Glcd_Fill(0xFF);                             // Fill Glcd

    Glcd_Set_Font(Font_Glcd_Character8x7, 8, 7, 32);  // Change font
    someText = "8x7 Font";
    Glcd_Write_Text(someText, 5, 0, 2);               // Write string
    Delay2s();

    Glcd_Set_Font(Font_Glcd_System3x5, 3, 5, 32);     // Change font
    someText = "3X5 CAPITALS ONLY";
    Glcd_Write_Text(someText, 60, 2, 2);              // Write string
    Delay2s();

    Glcd_Set_Font(Font_Glcd_5x7, 5, 7, 32);           // Change font
    someText = "5x7 Font";
    Glcd_Write_Text(someText, 5, 4, 2);               // Write string
    Delay2s();

    Glcd_Set_Font(Font_Glcd_System5x7, 5, 7, 32);     // Change font
    someText = "5x7 Font (v2)";
    Glcd_Write_Text(someText, 50, 6, 2);              // Write string
    Delay2s();
  }
}