/*
 * Project name:
     Sound (Usage of Sound library)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This project is a simple demonstration of how to
     use sound library for playing tones on a piezo speaker.
 * Test configuration:
     MCU:             dsPIC30F6014A
                      http://ww1.microchip.com/downloads/en/DeviceDoc/70143D.pdf
     Dev.Board:       UNI-DS6 - ac:Piezo
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      XT-PLL8, 80.000MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
 * NOTES:
     - Connect jumper J14 to RC1. (board specific)
     - Put button jumper (J17) into VCC position and
       pull-down pins RB7...RB3 on PORTB. (board specific)
*/

void Tone1() {
  Sound_Play(659, 250);   // Frequency = 659Hz, duration = 250ms
}

void Tone2() {
  Sound_Play(698, 250);   // Frequency = 698Hz, duration = 250ms
}

void Tone3() {
  Sound_Play(784, 250);   // Frequency = 784Hz, duration = 250ms
}

void Melody() {           // Plays the melody "Yellow house"
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3();
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3();
  Tone3(); Tone3(); Tone2(); Tone2(); Tone1();
}

void ToneA() {
  Sound_Play( 880, 50);
}
void ToneC() {
  Sound_Play(1046, 50);
}
void ToneE() {
  Sound_Play(1318, 50);
}

void Melody2() {
  unsigned short i;
  for (i = 9; i > 0; i--) {
    ToneA(); ToneC(); ToneE();
  }
}

void main() {

  ADPCFG = 0xFFFF;                  // Configure AN pins as digital
  TRISB = 0xF8;                     // Configure RB7..RB3 as input
  LATB = 0;
  
  Sound_Init(&PORTC, 1);
  Sound_Play(880, 1000);            // Play sound at 880Hz for 1 second

  while (1) {
    if (Button(&PORTB,7,1,1))       // RB7 plays Tone1
      Tone1();
    while (RB7_bit);                // Wait for button to be released

    if (Button(&PORTB,6,1,1))       // RB6 plays Tone2
      Tone2();
    while (RB6_bit);                // Wait for button to be released

    if (Button(&PORTB,5,1,1))       // RB5 plays Tone3
      Tone3();
    while (RB5_bit);                // Wait for button to be released

    if (Button(&PORTB,4,1,1))       // RB4 plays Melody2
      Melody2();
    while (RB4_bit);                // Wait for button to be released

    if (Button(&PORTB,3,1,1))       // RB3 plays Melody
      Melody();
    while (RB4_bit);                // Wait for button to be released
  }
}